@@ -2,7 +2,7 @@
 #
 # p7zr library
 #
-# Copyright (c) 2019-2021 Hiroshi Miura <miurahr@linux.com>
+# Copyright (c) 2019-2023 Hiroshi Miura <miurahr@linux.com>
 # Copyright (c) 2004-2015 by Joachim Bauch, mail@joachim-bauch.de
 # 7-Zip Copyright (C) 1999-2010 Igor Pavlov
 # LZMA SDK Copyright (C) 1999-2010 Igor Pavlov
@@ -24,6 +24,7 @@
 import bz2
 import lzma
 import struct
+import sys
 import zlib
 from abc import ABC, abstractmethod
 from enum import Enum
@@ -263,20 +264,20 @@ class DeflateDecompressor(ISevenZipDecompressor):
 class Deflate64Compressor(ISevenZipCompressor):
     def __init__(self):
         self.flushed = False
-        if inflate64 is not None:
+        if hasattr(sys, "pypy_version_info"):
+            self._enabled = False  # compression on pypy is disabled
+        else:
             self._compressor = inflate64.Deflater()
             self._enabled = True
-        else:
-            self._enabled = False
 
     def compress(self, data: Union[bytes, bytearray, memoryview], max_length: int = -1) -> bytes:
         if not self._enabled:
-            raise UnsupportedCompressionMethodError(None, "inflate64 is not installed.")
+            raise UnsupportedCompressionMethodError(None, "deflate64 is disabled on pypy.")
         return self._compressor.deflate(data)
 
     def flush(self) -> bytes:
         if not self._enabled:
-            raise UnsupportedCompressionMethodError(None, "inflate64 is not installed.")
+            raise UnsupportedCompressionMethodError(None, "deflate64 is disabled on pypy.")
         if self.flushed:
             return b""
         self.flushed = True
@@ -286,15 +287,15 @@ class Deflate64Compressor(ISevenZipCompressor):
 class Deflate64Decompressor(ISevenZipDecompressor):
     def __init__(self):
         self.flushed = False
-        if inflate64 is not None:
+        if hasattr(sys, "pypy_version_info"):
+            self._enabled = False
+        else:
             self._decompressor = inflate64.Inflater()
             self._enabled = True
-        else:
-            self._enabled = False
 
     def decompress(self, data: Union[bytes, bytearray, memoryview], max_length: int = -1) -> bytes:
         if not self._enabled:
-            raise UnsupportedCompressionMethodError(None, "inflate64 is not installed.")
+            raise UnsupportedCompressionMethodError(None, "deflate64 is disabled on pypy.")
         if len(data) == 0:
             if self.flushed:
                 return b""
@@ -531,7 +532,7 @@ class ZstdDecompressor(ISevenZipDecompressor):
         return self.decompressor.decompress(data)
 
 
-algorithm_class_map = {
+algorithm_class_map: Dict[int, Tuple[Any, Any]] = {
     FILTER_ZSTD: (ZstdCompressor, ZstdDecompressor),
     FILTER_BROTLI: (BrotliCompressor, BrotliDecompressor),
     FILTER_PPMD: (PpmdCompressor, PpmdDecompressor),
@@ -545,7 +546,7 @@ algorithm_class_map = {
     FILTER_ARMTHUMB: (BcjArmtEncoder, BcjArmtDecoder),
     FILTER_POWERPC: (BcjPpcEncoder, BcjPpcDecoder),
     FILTER_SPARC: (BcjSparcEncoder, BcjSparcDecoder),
-}  # type: Dict[int, Tuple[Any, Any]]
+}
 
 
 class LZMA1Decompressor(ISevenZipDecompressor):
